@@ -44,6 +44,10 @@ SCM robot_grab (void);
 SCM robot_zap (void);
 SCM robot_stop (void);
 
+SCM robot_get_sheilds (void);
+SCM robot_get_energy (void);
+SCM robot_get_score (void);
+
 int what_thing (const char *th);
 
 #endif /* _API_H */
