@@ -1,6 +1,6 @@
 #include <stdio.h>
-#include <stdlib.h>				/* for rand */
-#include <time.h>				/* for time */
+#include <stdlib.h>		/* for rand */
+#include <time.h>		/* for time */
 
 #include <gh.h>
 
@@ -14,10 +14,12 @@ scm_random (SCM s_n)
   int n;
 
   n = gh_scm2int (s_n);
-  result = (int) ((double)rand() / ((double)RAND_MAX + 1.0) * n);
 
-  /* If you're worried about using floating point, you could use
-     result = (int) (rand() / (RAND_MAX / n + 1)); */
+  /* If you don't mind using floating point, you can use */
+  /*  result = (int) ((double) rand () / ((double) RAND_MAX + 1.0) * n); */
+
+  /* If you're worried about using floating point, you could use */
+     result = (int) (rand() / (RAND_MAX / n + 1));
 
   /* Both methods obviously require knowing RAND_MAX (which ANSI
      #defines in <stdlib.h>), and assume that N is much less than
@@ -25,7 +27,7 @@ scm_random (SCM s_n)
 
   /* References: K&R2 Sec. 7.8.7 p. 168; PCS Sec. 11 p. 172. */
 
-  return (gh_int2scm (n));
+  return (gh_int2scm (result));
 }
 
 SCM
